Learn R Programming

r2pmml (version 0.31.0)

decorate: Dispatches execution to the most appropriate model decoration function.

Description

Dispatches execution to the most appropriate model decoration function.

Usage

decorate(x, ...)

Arguments

x

A model object.

...

Arguments to pass on to the selected function.