Decorates a "WrappedModel" object with "invert_levels" element. Additionally, decorates the learned model with model type-dependent elements.
# S3 method for WrappedModel
decorate(x, invert_levels = FALSE, ...)A "WrappedModel" object.
A flag indicating if the learned model should assume normal (FALSE) or inverted (TRUE) ordering of category values for the binary categorical target field.
Arguments to pass on to the "decorate.default" function