Learn R Programming

r2pmml (version 0.31.0)

verify: Dispatches execution to the most appropriate model verification function.

Description

Dispatches execution to the most appropriate model verification function.

Usage

verify(x, newdata, ...)

Arguments

x

A model object.

newdata

The verification dataset.

...

Arguments to pass on to the selected function.